==> enx_uikit_flutter-1.0.3.tar.gz: lib/models/user_list_model.dart <==
import 'dart:convert';
/// vidoeEnabled : true
/// role : "participant"
/// clientId : "b7c720d9-1c38-40c7-8c47-683e50bf9ef4"
/// videoMuted : false
/// data : {"name":"abc","age":12,"email":"zzbz@qq"}
/// permissions : {"subscribe":true,"stats":true,"publish":true,"record":false,"controlhandlers":true}
/// name : "5fcb"
/// audioMuted : false
/// audioEnabled : true
/// user_ref : "5fcb"


ParticipantsList activeTalkerFromJson(String str) => ParticipantsList.fromJson(json.decode(str));
String activeTalkerToJson(ParticipantsList data) => json.encode(data.toJson());
class ParticipantsList {
  ParticipantsList({
    List<UserListModel>? activeList,}){
    _activeList = activeList;
  }

  ParticipantsList.fromJson(dynamic json) {
    if (json['userList'] != null) {
      _activeList = [];
      json['userList'].forEach((v) {
        _activeList?.add(UserListModel.fromJson(v));
      });
    }
  }
  List<UserListModel>? _activeList;

  List<UserListModel>? get activeList => _activeList;

  Map<String, dynamic> toJson() {
    final map = <String, dynamic>{};
    if (_activeList != null) {
      map['userList'] = _activeList?.map((v) => v.toJson()).toList();
    }
    return map;
  }

}


UserListModel userListModelFromJson(String str) => UserListModel.fromJson(json.decode(str));
String userListModelToJson(UserListModel data) => json.encode(data.toJson());
class UserListModel {
  UserListModel({
    bool? vidoeEnabled,
    String? role,
    String? clientId,
    bool? videoMuted,
    //Data? data,
    Permissions? permissions,
    String? name,
    bool? audioMuted,
    bool? audioEnabled,
    String? userRef,}){
    _vidoeEnabled = vidoeEnabled;
    _role = role;
    _clientId = clientId;
    _videoMuted = videoMuted;
  //  _data = data;
    _permissions = permissions;
    _name = name;
    _audioMuted = audioMuted;
    _audioEnabled = audioEnabled;
    _userRef = userRef;
  }

  UserListModel.fromJson(dynamic json) {
    _vidoeEnabled = json['vidoeEnabled'];
    _role = json['role'];
    _clientId = json['clientId'];
    _videoMuted = json['videoMuted'];
  //  _data = json['data'] != null ? Data.fromJson(json['data']) : null;
    _permissions = json['permissions'] != null ? Permissions.fromJson(json['permissions']) : null;
    _name = json['name'];
    _audioMuted = json['audioMuted'];
    _audioEnabled = json['audioEnabled'];
    _userRef = json['user_ref'];
  }
  bool? _vidoeEnabled;
  String? _role;
  String? _clientId;
  bool? _videoMuted;
  //Data? _data;
  Permissions? _permissions;
  String? _name;
  bool? _audioMuted;
  bool? _audioEnabled;
  String? _userRef;

  bool? get vidoeEnabled => _vidoeEnabled;
  String? get role => _role;
  String? get clientId => _clientId;
  bool? get videoMuted => _videoMuted;
 // Data? get data => _data;
  Permissions? get permissions => _permissions;
  String? get name => _name;
  bool? get audioMuted => _audioMuted;
  bool? get audioEnabled => _audioEnabled;
  String? get userRef => _userRef;

  Map<String, dynamic> toJson() {
    final map = <String, dynamic>{};
    map['vidoeEnabled'] = _vidoeEnabled;
    map['role'] = _role;
    map['clientId'] = _clientId;
    map['videoMuted'] = _videoMuted;
   /* if (_data != null) {
      map['data'] = _data?.toJson();
    }*/
    if (_permissions != null) {
      map['permissions'] = _permissions?.toJson();
    }
    map['name'] = _name;
    map['audioMuted'] = _audioMuted;
    map['audioEnabled'] = _audioEnabled;
    map['user_ref'] = _userRef;
    return map;
  }

}

/// subscribe : true
/// stats : true
/// publish : true
/// record : false
/// controlhandlers : true

Permissions permissionsFromJson(String str) => Permissions.fromJson(json.decode(str));
String permissionsToJson(Permissions data) => json.encode(data.toJson());
class Permissions {
  Permissions({
    bool? subscribe,
    bool? stats,
    bool? publish,
    bool? record,
    bool? controlhandlers,}){
    _subscribe = subscribe;
    _stats = stats;
    _publish = publish;
    _record = record;
    _controlhandlers = controlhandlers;
  }

  Permissions.fromJson(dynamic json) {
    _subscribe = json['subscribe'];
    _stats = json['stats'];
    _publish = json['publish'];
    _record = json['record'];
    _controlhandlers = json['controlhandlers'];
  }
  bool? _subscribe;
  bool? _stats;
  bool? _publish;
  bool? _record;
  bool? _controlhandlers;

  bool? get subscribe => _subscribe;
  bool? get stats => _stats;
  bool? get publish => _publish;
  bool? get record => _record;
  bool? get controlhandlers => _controlhandlers;

  Map<String, dynamic> toJson() {
    final map = <String, dynamic>{};
    map['subscribe'] = _subscribe;
    map['stats'] = _stats;
    map['publish'] = _publish;
    map['record'] = _record;
    map['controlhandlers'] = _controlhandlers;
    return map;
  }

}

/// name : "abc"
/// age : 12
/// email : "zzbz@qq"

/*
Data dataFromJson(String str) => Data.fromJson(json.decode(str));
String dataToJson(Data data) => json.encode(data.toJson());
class Data {
  Data({
    String? name,
    int? age,
    String? email,}){
    _name = name;
    _age = age;
    _email = email;
  }

  Data.fromJson(dynamic json) {
    _name = json['name'];
    _age = json['age'];
    _email = json['email'];
  }
  String? _name;
  int? _age;
  String? _email;

  String? get name => _name;
  int? get age => _age;
  String? get email => _email;

  Map<String, dynamic> toJson() {
    final map = <String, dynamic>{};
    map['name'] = _name;
    map['age'] = _age;
    map['email'] = _email;
    return map;
  }

}*/

==> enx_uikit_flutter-1.9.8.tar.gz: lib/models/user_list_model.dart <==
import 'dart:convert';

/// vidoeEnabled : true
/// role : "participant"
/// clientId : "b7c720d9-1c38-40c7-8c47-683e50bf9ef4"
/// videoMuted : false
/// data : {"name":"abc","age":12,"email":"zzbz@qq"}
/// permissions : {"subscribe":true,"stats":true,"publish":true,"record":false,"controlhandlers":true}
/// name : "5fcb"
/// audioMuted : false
/// audioEnabled : true
/// user_ref : "5fcb"

ParticipantsList activeTalkerFromJson(String str) =>
    ParticipantsList.fromJson(json.decode(str));
String activeTalkerToJson(ParticipantsList data) => json.encode(data.toJson());

/// subscribe : true
/// stats : true
/// publish : true
/// record : false
/// controlhandlers : true

Permissions permissionsFromJson(String str) =>
    Permissions.fromJson(json.decode(str));

String permissionsToJson(Permissions data) => json.encode(data.toJson());
UserListModel userListModelFromJson(String str) =>
    UserListModel.fromJson(json.decode(str));
String userListModelToJson(UserListModel data) => json.encode(data.toJson());

class ParticipantsList {
  List<UserListModel>? _activeList;

  ParticipantsList({
    List<UserListModel>? activeList,
  }) {
    _activeList = activeList;
  }
  ParticipantsList.fromJson(dynamic json) {
    if (json['userList'] != null) {
      _activeList = [];
      json['userList'].forEach((v) {
        _activeList?.add(UserListModel.fromJson(v));
      });
    }
  }

  List<UserListModel>? get activeList => _activeList;

  Map<String, dynamic> toJson() {
    final map = <String, dynamic>{};
    if (_activeList != null) {
      map['userList'] = _activeList?.map((v) => v.toJson()).toList();
    }
    return map;
  }
}

class Permissions {
  bool? _subscribe;

  bool? _stats;
  bool? _publish;
  bool? _record;
  bool? _controlhandlers;
  Permissions({
    bool? subscribe,
    bool? stats,
    bool? publish,
    bool? record,
    bool? controlhandlers,
  }) {
    _subscribe = subscribe;
    _stats = stats;
    _publish = publish;
    _record = record;
    _controlhandlers = controlhandlers;
  }
  Permissions.fromJson(dynamic json) {
    _subscribe = json['subscribe'];
    _stats = json['stats'];
    _publish = json['publish'];
    _record = json['record'];
    _controlhandlers = json['controlhandlers'];
  }

  bool? get controlhandlers => _controlhandlers;
  bool? get publish => _publish;
  bool? get record => _record;
  bool? get stats => _stats;
  bool? get subscribe => _subscribe;

  Map<String, dynamic> toJson() {
    final map = <String, dynamic>{};
    map['subscribe'] = _subscribe;
    map['stats'] = _stats;
    map['publish'] = _publish;
    map['record'] = _record;
    map['controlhandlers'] = _controlhandlers;
    return map;
  }
}

class UserListModel {
  bool? _vidoeEnabled;

  String? _role;
  String? _clientId;
  bool? _videoMuted;
  Permissions? _permissions;
  String? _name;
  //Data? _data;
  bool? _audioMuted;
  bool? _audioEnabled;
  String? _userRef;
  UserListModel({
    bool? vidoeEnabled,
    String? role,
    String? clientId,
    bool? videoMuted,
    //Data? data,
    Permissions? permissions,
    String? name,
    bool? audioMuted,
    bool? audioEnabled,
    String? userRef,
  }) {
    _vidoeEnabled = vidoeEnabled;
    _role = role;
    _clientId = clientId;
    _videoMuted = videoMuted;
    //  _data = data;
    _permissions = permissions;
    _name = name;
    _audioMuted = audioMuted;
    _audioEnabled = audioEnabled;
    _userRef = userRef;
  }
  UserListModel.fromJson(dynamic json) {
    _vidoeEnabled = json['vidoeEnabled'];
    _role = json['role'];
    _clientId = json['clientId'];
    _videoMuted = json['videoMuted'];
    //  _data = json['data'] != null ? Data.fromJson(json['data']) : null;
    _permissions = json['permissions'] != null
        ? Permissions.fromJson(json['permissions'])
        : null;
    _name = json['name'];
    _audioMuted = json['audioMuted'];
    _audioEnabled = json['audioEnabled'];
    _userRef = json['user_ref'];
  }

  bool? get audioEnabled => _audioEnabled;
  bool? get audioMuted => _audioMuted;
  String? get clientId => _clientId;
  String? get name => _name;
  // Data? get data => _data;
  Permissions? get permissions => _permissions;
  String? get role => _role;
  String? get userRef => _userRef;
  bool? get videoMuted => _videoMuted;
  bool? get vidoeEnabled => _vidoeEnabled;

  Map<String, dynamic> toJson() {
    final map = <String, dynamic>{};
    map['vidoeEnabled'] = _vidoeEnabled;
    map['role'] = _role;
    map['clientId'] = _clientId;
    map['videoMuted'] = _videoMuted;
    /* if (_data != null) {
      map['data'] = _data?.toJson();
    }*/
    if (_permissions != null) {
      map['permissions'] = _permissions?.toJson();
    }
    map['name'] = _name;
    map['audioMuted'] = _audioMuted;
    map['audioEnabled'] = _audioEnabled;
    map['user_ref'] = _userRef;
    return map;
  }
}

/// name : "abc"
/// age : 12
/// email : "zzbz@qq"

/*
Data dataFromJson(String str) => Data.fromJson(json.decode(str));
String dataToJson(Data data) => json.encode(data.toJson());
class Data {
  Data({
    String? name,
    int? age,
    String? email,}){
    _name = name;
    _age = age;
    _email = email;
  }

  Data.fromJson(dynamic json) {
    _name = json['name'];
    _age = json['age'];
    _email = json['email'];
  }
  String? _name;
  int? _age;
  String? _email;

  String? get name => _name;
  int? get age => _age;
  String? get email => _email;

  Map<String, dynamic> toJson() {
    final map = <String, dynamic>{};
    map['name'] = _name;
    map['age'] = _age;
    map['email'] = _email;
    return map;
  }

}*/
